<?php
/*
 * Plugin Name: Goldnet Sip Simple
 * Plugin URI: https://telcoservices.com.au
 * Description: Sip plugin (simple)
 * Author: Goldnet Australia
 * Author URI: https://goldnetgroup.com.au
 * Version: 1.0.0
 */

function goldnet_sipHtmlSimple($params)
{
    $options = get_option('goldnet_sip_plugin_options_simple');
    if ($options['mode'] != 'caller') {
        $html = 'Plugin is not in caller mode. Please check your settings!';
        return $html;
    }
    $timestamp = time();
    $callee = $options["callee"];
    $icon = $options["icon"];
    $username = $options['private_identity'];
    $password = $options['password'];
    $impu = $options['public_identity'];
    $formId = $callee . '-' . $timestamp;
    wp_enqueue_script('sipml-api', plugins_url('js/SIPml-api.min.js', __FILE__), array('jquery'));
    wp_enqueue_style('sip-css', plugins_url('css/style.css', __FILE__));
    $localVariables = "var realm = '{$options['realm']}';\n";
    $localVariables .= "var impi = '$username';\n";
    $localVariables .= "var impu = '$impu';\n";
    $localVariables .= "var passwd = '$password';\n";
    $localVariables .= "var websocket_proxy_url = '{$options['websocket_server_url']}';\n";
    $localVariables .= "var ice_servers = '{$options['ice_servers']}';\n";
    wp_enqueue_script('goldnet-sip', plugins_url('js/sip_script.js', __FILE__));
    wp_add_inline_script( 'goldnet-sip', $localVariables, 'before' );

    static $i = 1;
    $html = "";
    if ($i == 1) {
        $html .= '<!-- Audios -->
          <audio id="audio_remote" autoplay="autoplay"></audio>
          <audio id="ringtone" loop="" src="' . plugins_url("sounds/ringtone.wav", __FILE__) . '"> </audio>
          <audio id="ringbacktone" loop="" src="' . plugins_url("sounds/ringbacktone.wav", __FILE__) . '"> </audio>
          <audio id="dtmfTone" src="' . plugins_url("sounds/dtmf.wav", __FILE__) . '"> </audio>';
    }
    $html .= file_get_contents(__DIR__ . '/callee.html');
    $icon = plugins_url("img/$icon.png", __FILE__);
    $html = str_replace("<!--formId-->", $formId, $html);
    $html = str_replace("<!--username-->", $username, $html);
    $html = str_replace("<!--password-->", $password, $html);
    $html = str_replace("<!--callee-->", $callee, $html);
    $html = str_replace("<!--icon-->", $icon, $html);
    $i++;
    return $html;
}

function goldnet_sipCallCenterSimple($params)
{
    $options = get_option('goldnet_sip_plugin_options_simple');
    if ($options['mode'] != 'callee') {
        $html = 'Plugin is not in callee mode. Please check your settings!';
        return $html;
    }
    $icon = $options["icon"];
    $username = $options['private_identity'];
    $password = $options['password'];
    $impu = $options['public_identity'];

    wp_enqueue_script('sipml-api', plugins_url('js/SIPml-api.min.js', __FILE__), array('jquery'));
    $localVariables = "var myUsername = '$username';\n";
    $localVariables .= "var realm = '{$options['realm']}';\n";
    $localVariables .= "var impi = '$username';\n";
    $localVariables .= "var impu = '$impu';\n";
    $localVariables .= "var passwd = '$password';\n";
    $localVariables .= "var websocket_proxy_url = '{$options['websocket_server_url']}';\n";
    $localVariables .= "var ice_servers = '{$options['ice_servers']}';\n";
    wp_enqueue_script('goldnet-sip', plugins_url('js/goldnet_sip.js', __FILE__));
    wp_add_inline_script( 'goldnet-sip', $localVariables, 'before' );
    wp_enqueue_style('sip-css', plugins_url('css/style.css', __FILE__));
    $icon = plugins_url("img/$icon.png", __FILE__);
    $html = file_get_contents(__DIR__ . '/call_center.html');
    $html = str_replace("<!--username-->", $username, $html);
    $html = str_replace("<!--password-->", $password, $html);
    $html = str_replace("<!--pluginPath-->", plugins_url('', __FILE__), $html);
    $html = str_replace("<!--icon-->", $icon, $html);
    return $html;
}

add_shortcode('goldnet-sip-call-center', 'goldnet_sipCallCenterSimple');
add_shortcode('goldnet-sip-form', 'goldnet_sipHtmlSimple');

/* Settings Section */
function goldnet_sip_settings_page_simple()
{
    add_options_page('Goldnet SIP Plugin (Simple) Settings', 'Goldnet SIP Plugin (Simple)', 'manage_options', 'goldnet-sip-settings-page-simple', 'goldnet_sip_render_plugin_settings_page_simple');
}

add_action('admin_menu', 'goldnet_sip_settings_page_simple');

function goldnet_sip_render_plugin_settings_page_simple()
{
    wp_enqueue_script('goldnet-sip-simple', plugin_dir_url(__FILE__) . 'js/functions.js', array('jquery'));
    wp_enqueue_style('sip-css', plugins_url('css/style.css', __FILE__));
    ?>
    <h2>Goldnet SIP Settings Page (Simple)</h2>
    <form action="options.php" method="post">
        <?php
        settings_fields('goldnet_sip_plugin_options_simple');
        do_settings_sections('goldnet_sip_plugin_simple'); ?>
        <input name="submit" class="button button-primary" type="submit" value="<?php esc_attr_e('Save'); ?>"/>
    </form>
    <?php
}


function goldnet_sip_register_settings_simple()
{
    register_setting('goldnet_sip_plugin_options_simple', 'goldnet_sip_plugin_options_simple', 'goldnet_sip_plugin_options_validate_simple');
    add_settings_section('sip_settings', 'WebRTC Server Settings', 'goldnet_sip_plugin_section_sip_simple', 'goldnet_sip_plugin_simple');

    add_settings_field('goldnet_sip_plugin_setting_realm', 'Realm', 'goldnet_sip_plugin_setting_form_field', 'goldnet_sip_plugin_simple', 'sip_settings', ['name' => 'realm', 'value' => 'sip.telcoservices.com.au:8089/ws']);
    add_settings_field('goldnet_sip_plugin_setting_websocket_server_url', 'WebSocket Server URL', 'goldnet_sip_plugin_setting_form_field', 'goldnet_sip_plugin_simple', 'sip_settings', ['name' => 'websocket_server_url', 'value' => 'wss://sip.telcoservices.com.au:8089/ws']);
    add_settings_field('goldnet_sip_plugin_setting_ice_servers', 'ICE Servers', 'goldnet_sip_plugin_setting_form_field', 'goldnet_sip_plugin_simple', 'sip_settings', ['name' => 'ice_servers', 'value' => '[]', 'help' => 'https://telcoservices.com.au']);

    add_settings_section('users_settings', 'Users Settings', 'goldnet_sip_plugin_section_users_simple', 'goldnet_sip_plugin_simple');

    add_settings_field('goldnet_sip_plugin_setting_private_identity', 'Private Identity', 'goldnet_sip_plugin_setting_form_field', 'goldnet_sip_plugin_simple', 'users_settings', ['name' => 'private_identity', 'value' => 'w1000']);
    add_settings_field('goldnet_sip_plugin_setting_public_identity', 'Public Identity', 'goldnet_sip_plugin_setting_form_field', 'goldnet_sip_plugin_simple', 'users_settings', ['name' => 'public_identity', 'value' => 'sip:w1000@sip.telcoservices.com.au']);
    add_settings_field('goldnet_sip_plugin_setting_password', 'Password', 'goldnet_sip_plugin_setting_form_field', 'goldnet_sip_plugin_simple', 'users_settings', ['name' => 'password', 'value' => 'w1000_129912345']);
    add_settings_field('goldnet_sip_plugin_setting_icon', 'Icon', 'goldnet_sip_plugin_setting_form_field', 'goldnet_sip_plugin_simple', 'users_settings', ['name' => 'icon', 'value' => 'callee1', 'type' => 'radio', 'radioOptions' => ['callee1', 'callee2', 'callee3']]);

    add_settings_section('caller_callee_settings', 'Caller/Callee Settings', 'goldnet_sip_plugin_section_caller_callee_simple', 'goldnet_sip_plugin_simple');
    add_settings_field('goldnet_sip_plugin_setting_mode', 'Mode', 'goldnet_sip_plugin_setting_form_mode', 'goldnet_sip_plugin_simple', 'caller_callee_settings');
    add_settings_field('goldnet_sip_plugin_setting_callee', 'Caller Destination', 'goldnet_sip_plugin_setting_form_field', 'goldnet_sip_plugin_simple', 'caller_callee_settings', ['name' => 'callee', 'value' => 'w1001']);
}

add_action('admin_init', 'goldnet_sip_register_settings_simple');

function goldnet_sip_plugin_options_validate($input)
{
    $newInput = $input;
    $newInput['realm'] = trim($input['realm']);
    return $newInput;
}

function goldnet_sip_plugin_section_sip_simple()
{
    echo '<p>Here you can set your SIP settings. For simplicity, Telcoservices demo settings are included. Make sure to save the settings before using them.</p>';
}

function goldnet_sip_plugin_section_users_simple()
{
    echo '<p>Here you can set your users</p>';
}

function goldnet_sip_plugin_section_caller_callee_simple()
{
    echo '<p>Here you can set caller/callee configurations</p>';
}

function goldnet_sip_plugin_setting_form_field($args)
{
    $options = get_option('goldnet_sip_plugin_options_simple');
    $name = $args["name"];
    $value = isset($options[$name]) ? $options[$name] : $args["value"];
    if (isset($args['type']) && $args['type'] == 'radio') {
        $description = '';
        foreach ($args['radioOptions'] as $radioValue) {
            if ($radioValue == 'caller') {
                $description = '(You should set the destination to call.)';
            }
            if ($radioValue == 'callee') {
                $description = '(Receiving calls on defined user earlier.)';
            }
            echo "<input name='goldnet_sip_plugin_options_simple[" . $name . "]' type='radio' value='" . $radioValue . "' " . ($radioValue == $value ? 'checked' : '') . " />";
            if ($args['name'] == 'icon') {
                echo "<img src='" . plugins_url('img/' . $radioValue . '.png', __FILE__) . "' width='64' />";
            } else {
                echo ucfirst($radioValue) . $description . '<br />';
            }
        }
    } else {
        echo "<input class='goldnet-settings-field' id='goldnet_sip_plugin_setting_" . $name . "' name='goldnet_sip_plugin_options_simple[" . $name . "]' type='text' value='" . $value . "' />";
    }
    if (isset($args['help'])) {
        echo '<div>Need help? Please click <a href="' . $args['help'] . '" target="_blank">here</a> for more information.</div>';
    }
}

function goldnet_sip_plugin_setting_form_mode()
{
    $options = get_option('goldnet_sip_plugin_options_simple');
    $value = isset($options['mode']) ? $options['mode'] : 'caller';
    ?>
    <div>
        <input id="caller-mode" name='goldnet_sip_plugin_options_simple[mode]' type='radio' value='caller' <?= $value == 'caller' ? 'checked' : '' ?> />Caller (You should set the destination to call.)
    </div>
    <div style="margin-top: 10px">
        <input id="callee-mode" name='goldnet_sip_plugin_options_simple[mode]' type='radio' value='callee' <?= $value == 'callee' ? 'checked' : '' ?> />Callee (Receiving calls on defined user earlier.)
    </div>
    <div id="shortcode_area" style="margin-top: 10px">
        <?php if ($value == 'caller'):?>
            Use this code to put an icon on your pages which enables your users to call you via SipMl5 protocol. <br/>
            <strong>[goldnet-sip-form]</strong>
        <?php else: ?>
            Use this code to have a call center on your pages to answer incoming calls. <br/>
            <strong>[goldnet-sip-call-center]</strong>
        <?php endif ?>
    </div>
    <?php
}

